diff --binary -Nru3 grx246/include/grx20.h tgrx246/include/grx20.h
--- grx246/include/grx20.h	2003-02-26 23:33:46.000000000 +0100
+++ tgrx246/include/grx20.h	2004-02-08 09:32:48.067160000 +0100
@@ -68,7 +68,6 @@
 #endif
 #ifdef __CYGWIN32__
 #define GRX_VERSION     GRX_VERSION_GCC_386_CYG32
-#define __WIN32__
 #endif
 #endif /* __GNUC__ */
 
diff --binary -Nru3 grx246/makedefs.grx tgrx246/makedefs.grx
--- grx246/makedefs.grx	2003-07-16 04:09:42.000000000 +0200
+++ tgrx246/makedefs.grx	2004-02-08 19:31:05.289044800 +0100
@@ -50,6 +50,8 @@
 LINUX_i386_X11        = $(SYSTEM_TAG_PREFIX).002
 DOS_DJGPP_V2          = $(SYSTEM_TAG_PREFIX).004
 WIN32_GCC_i386_STATIC = $(SYSTEM_TAG_PREFIX).006
+WIN32_GCC_i386_CYGWIN = $(SYSTEM_TAG_PREFIX).007
+WIN32_GCC_i386_CYGMING= $(SYSTEM_TAG_PREFIX).008
 
 ifdef   DEBUG
 CCOPT = -O2 -Wall -g -DDEBUG=$(DEBUG)
@@ -194,3 +196,88 @@
 
 ######################################################################
 
+### CYGMING SPECIFIC #################################################
+# For creation
+# Libraries and DLLs go into ./lib/win32
+# Cygwin DLL is called cygGRX20.dll
+# MinGW  DLL is called    GRX20.dll
+# For install:
+# Cygwin library goes into /usr/local/lib
+# MinGW  library goes into /usr/local/lib/mingw
+# DLLs go nowhere, as I have no idea where they should go
+#
+#
+ifdef GRXVC32
+
+GRX_LIB_SUBDIR=win32
+
+TARGET= native
+#TARGET = mingw
+FDRIVER= native
+# FDRIVER= X11
+
+HEADERDIR=/usr/local/include/grx20
+
+ifeq ($(TARGET), native)
+  $(warning Compile-mode=native)
+  GRX_DEFAULT_FONT_PATH=/usr/local/lib/fonts/grx
+  ifeq ($(FDRIVER), native)
+    $(warning Framedriver=native)
+    LIBDIR = /usr/local/lib
+    EXECDIR= /usr/local/bin
+    DLLPREFIX = cyg
+  else 
+    ifeq ($(FDRIVER), X11)
+     $(warning Framedriver is X11)
+     # The X11 base dir on your system
+     X11BASE=/usr/X11R6
+
+     # Add directories with X11 include files here
+     X11INCS=-I$(X11BASE)/include
+
+     # put X11 required libraries and directories here
+     # note: some systems need -lsocket added
+     X11LIBS=-L$(X11BASE)/lib -lX11
+
+     LIBDIR = $(X11BASE)/lib
+     EXECDIR = /usr/X11R6/bin
+     DLLPREFIX = cygX
+    else
+     $(error Invalid FDRIVER: $(FDRIVER))
+    endif
+  endif
+else
+  $(warning Compile-mode=mingw)
+  CC = gcc -mno-cygwin
+  FDRIVER = native
+  # Only native driver is supported anyway. 
+endif
+#
+# These lines should maybe go to the main part ???
+#
+ifeq ($(HAVE_LIBTIFF),y)
+  ADDON_LIBS += -ltiff
+endif
+
+ifeq ($(HAVE_LIBJPEG),y)
+  ADDON_LIBS += -ljpeg
+endif
+
+ifeq ($(HAVE_LIBPNG),y)
+  ADDON_LIBS += -lpng
+endif
+
+ifeq ($(NEED_ZLIB),y)
+  ADDON_LIBS += -lz
+endif
+
+ifeq ($(INCLUDE_SHARED_SUPPORT),y)
+  ifeq ($(FDRIVER), X11)
+    ADDON_LIBS +=  -L $(LIBDIR)
+  else
+    ADDON_LIBS += -lgdi32
+  endif
+endif
+
+endif
+#######################################################################
diff --binary -Nru3 grx246/makefile.cyg tgrx246/makefile.cyg
--- grx246/makefile.cyg	1970-01-01 01:00:00.000000000 +0100
+++ tgrx246/makefile.cyg	2004-01-24 09:19:24.872267200 +0100
@@ -0,0 +1,72 @@
+#
+# GRX makefile for Cygwin build environment.
+# It is mostly stolen from the MinGW-original and adopted
+# to the cygwin environment. See "makedefs.grx" for details
+#
+# This file is mpstly stolen from makefile.w32
+#
+.PHONY : libs test bgitest clean cleanall install uninstall \
+	 install-bin uninstall-bin install-fonts uninstall-fonts
+
+GRXVC32=y
+
+include makedefs.grx
+RM = /bin/rm -f
+CP = /bin/cp
+INSTALL=/bin/install
+SHELL=/bin/bash
+MAKEFILE= makefile.cyg
+export MAKEFILE RM CP INSTALL GRXVC32
+
+all:   libs test bgitest
+
+libs:
+	$(MAKE) -C src -f $(MAKEFILE)
+
+test:   libs
+	$(MAKE) -C test -f $(MAKEFILE)
+ifeq ($(INCLUDE_GPC_SUPPORT),y)
+	$(MAKE) -C pascal -f $(MAKEFILE)
+endif
+
+bgitest:   libs
+ifeq ($(INCLUDE_BGI_SUPPORT),y)
+	$(MAKE) -C test/bgi -f $(MAKEFILE)
+ifeq ($(INCLUDE_GPC_SUPPORT),y)
+	$(MAKE) -C pascal/bgi -f $(MAKEFILE)
+endif
+endif
+
+clean:
+	$(MAKE) -C test -f $(MAKEFILE) clean
+ifeq ($(INCLUDE_BGI_SUPPORT),y)
+	$(MAKE) -C test/bgi -f $(MAKEFILE) clean
+endif
+	$(MAKE) -C src  -f $(MAKEFILE) clean
+ifeq ($(INCLUDE_GPC_SUPPORT),y)
+	$(MAKE) -C pascal -f $(MAKEFILE) clean
+ifeq ($(INCLUDE_BGI_SUPPORT),y)
+	$(MAKE) -C pascal/bgi -f $(MAKEFILE) clean
+endif
+endif
+
+cleanall: clean
+	$(MAKE) -C src -f $(MAKEFILE) cleanall
+
+install:
+	$(MAKE) -C src -f $(MAKEFILE) install
+
+uninstall:
+	$(MAKE) -C src -f $(MAKEFILE) uninstall
+
+install-bin:
+	$(MAKE) -C src -f $(MAKEFILE) install-bin
+
+uninstall-bin:
+	$(MAKE) -C src -f $(MAKEFILE) uninstall-bin
+
+install-fonts:
+	$(MAKE) -C src -f $(MAKEFILE) install-fonts
+
+uninstall-fonts:
+	$(MAKE) -C src -f $(MAKEFILE) uninstall-fonts
diff --binary -Nru3 grx246/src/fdrivers/ftable.c tgrx246/src/fdrivers/ftable.c
--- grx246/src/fdrivers/ftable.c	2003-04-02 23:24:56.000000000 +0200
+++ tgrx246/src/fdrivers/ftable.c	2004-01-23 15:48:18.842332800 +0100
@@ -54,7 +54,7 @@
     &_GrFrameDriverXWIN32L,
     &_GrFrameDriverXWIN32H,
 #endif
-#ifdef __WIN32__
+#if defined(__WIN32__) || defined (W32NATIVE_DRIVER)
     &_GrFrameDriverWIN32_8,
     &_GrFrameDriverWIN32_24,
 #endif
diff --binary -Nru3 grx246/src/include/grxdebug.h tgrx246/src/include/grxdebug.h
--- grx246/src/include/grxdebug.h	2001-01-21 06:30:30.000000000 +0100
+++ tgrx246/src/include/grxdebug.h	2004-01-28 21:46:04.097468800 +0100
@@ -31,7 +31,7 @@
 extern int   _GR_debug_flags;
 extern void  _GR_debug_printf(char *fmt,...);
 
-# ifdef __GNUC__
+# if defined( __GNUC__)||defined(__CYGWIN32__)||defined(__MINGW32__)
   extern char *_GR_debug_function;
 #  define DBGPRINTF(tst,x) do {           \
      if ((tst)&_GR_debug_flags) {         \
diff --binary -Nru3 grx246/src/include/libwin32.h tgrx246/src/include/libwin32.h
--- grx246/src/include/libwin32.h	2003-03-30 19:58:22.000000000 +0200
+++ tgrx246/src/include/libwin32.h	2004-02-08 16:39:17.754942400 +0100
@@ -39,7 +39,7 @@
 
 extern HWND hGRXWnd;
 extern HDC hDCMem;
-extern HANDLE windowThread;
+// extern HANDLE windowThread; any use in exporting this?
 
 extern int _GrIsKbdEnabled(void);
 extern int _GrKeyPressed(void);
diff --binary -Nru3 grx246/src/makefile.cyg tgrx246/src/makefile.cyg
--- grx246/src/makefile.cyg	1970-01-01 01:00:00.000000000 +0100
+++ tgrx246/src/makefile.cyg	2004-02-08 16:43:24.109182400 +0100
@@ -0,0 +1,238 @@
+#
+# GRX Library Makefile for Cygwin
+#
+# See ../makdefs.grx for details
+#
+.PHONY : clean cleanall install uninstall \
+	 install-bin uninstall-bin install-fonts uninstall-fonts
+
+include ../makedefs.grx
+
+INCDIR= -I. -I./include -I../include
+
+ifeq ($(FDRIVER), X11)
+ CCOPT  += -D__XWIN__
+ INCDIR += $(X11INCS)
+else
+ CCOPT += -DW32NATIVE_DRIVER
+endif
+
+ifdef GRX_DEFAULT_FONT_PATH
+CCOPT += -DGRX_DEFAULT_FONT_PATH=\"$(GRX_DEFAULT_FONT_PATH)\"
+endif
+
+ifeq ($(TARGET), native)
+TAG = $(WIN32_GCC_i386_CYGWIN)
+else
+TAG = $(WIN32_GCC_i386_CYGMING)
+endif
+
+GRX20ln    = libgrx20.a
+GRX20ST    = ../lib/$(GRX_LIB_SUBDIR)/$(GRX20ln)
+
+ifeq ($(INCLUDE_SHARED_SUPPORT),y)
+GRX20sn    = $(DLLPREFIX)GRX20.dll
+GRX20SH    = ../lib/$(GRX_LIB_SUBDIR)/$(GRX20sn)
+GRX20IMP   = ../lib/$(GRX_LIB_SUBDIR)/lib$(GRX20sn).a
+endif
+
+OX=.o
+OP=
+
+include ./stdobjs.mak
+
+STD_O= $(STD_1) $(STD_2)  $(STD_3)  $(STD_4) \
+       $(STD_5) $(STD_6)  $(STD_7)  $(STD_8) \
+       $(STD_9) $(STD_10) $(STD_11) $(STD_12)\
+
+BGI_O= $(BGI_1) $(BGI_2)  $(BGI_3)  $(BGI_4) \
+       $(BGI_5) $(BGI_6)
+
+ADDON_O=
+ifdef DEBUG
+ ADDON_O += $(DBG_1)
+endif
+
+ifeq ($(HAVE_LIBTIFF),y)
+  ADDON_O += $(TIF_1)
+endif
+
+ifeq ($(HAVE_LIBJPEG),y)
+  ADDON_O += $(JPG_1)
+else
+  ADDON_O += $(NOJPG_1)
+endif
+
+ifeq ($(HAVE_LIBPNG),y)
+  ADDON_O += $(PNG_1)
+else
+  ADDON_O += $(NOPNG_1)
+endif
+
+ifeq ($(INCLUDE_PRINTING_CODE),y)
+  ADDON_O += $(PRN_1)
+  INCDIR += -I../addons/print
+ifeq ($(INCLUDE_BGI_SUPPORT),y)
+  BGI_Ob += $(PRNBGI_1)
+endif
+endif
+
+ifeq ($(INCLUDE_BMP_CODE),y)
+  ADDON_O += $(BMP_1)
+  INCDIR  += -I../addons/bmp
+endif
+
+W32_O = $(ADDON_O)              \
+	fdrivers/fdw32_24.o     \
+	fdrivers/fdw32_8.o      \
+	fdrivers/lfbbltrv.o     \
+	fdrivers/lfbbltvr.o     \
+	fdrivers/lfbbltvv.o     \
+	fdrivers/ram24.o        \
+	fdrivers/ram32l.o       \
+	fdrivers/ram32h.o       \
+	mouse/w32inp.o          \
+	mouse/w32keys.o         \
+	misc/w32misc.o          \
+	vdrivers/vd_win32.o
+X11_O = $(ADDON_O)          \
+        fdrivers/fd_xwin.o  \
+        fdrivers/ram24.o    \
+        fdrivers/ram32l.o   \
+        fdrivers/ram32h.o   \
+        fonts/fdv_xwin.o    \
+        mouse/xwininp.o     \
+        mouse/xwinkeys.o    \
+        misc/x11misc.o      \
+        vdrivers/vd_xwin.o
+
+ifeq ($(FDRIVER),native)
+ALL_O = $(STD_O) $(W32_O)
+else
+ALL_O = $(STD_O) $(X11_O)
+endif
+
+ifeq ($(INCLUDE_BGI_SUPPORT),y)
+  ALL_O += $(BGI_O)
+endif
+
+UTILPC= ../bin/bin2c.exe        \
+	../bin/fnt2c.exe        \
+
+UTILPW= ../bin/modetest.exe
+
+all:    $(GRX20ST) libsh $(UTILPC) $(UTILPW)
+
+clean:
+	for i in bgi draw fdrivers fonts image gformats mouse misc pattern\
+                 setup shape text user utils utilprog vdrivers wideline; \
+        do \
+	  $(RM) $$i/*.o ; \
+	done
+	$(RM) $(SYSTEM_TAG_PREFIX).*
+	$(RM) ../addons/*.o ../addons/print/*.o ../addons/bmp/*.o
+
+cleanall: clean
+	$(RM) $(GRX20ST) $(GRX20SH) $(UTILPC) $(UTILPW) $(GRX20IMP)
+	$(RM) ../test/*.dll
+
+install: $(GRX20ST)
+	$(INSTALL) -d $(LIBDIR)
+	$(INSTALL) -d $(HEADERDIR)
+	$(INSTALL) -m 644 $(GRX20ST) $(LIBDIR)
+	$(INSTALL) -m 644 ../include/{grx20,grxkeys,libbcc}.h $(HEADERDIR)
+ifeq ($(INCLUDE_PRINTING_CODE),y)
+	$(INSTALL) -m 644 ../addons/grxprint.h $(HEADERDIR)
+endif
+#ifeq ($(INCLUDE_GPC_SUPPORT),y)
+#	if not exist $(MINGWDIR)\units\nul mkdir $(MINGWDIR)\units
+#	copy ..\pascal\grx.pas $(MINGWDIR)\units
+#	copy ..\pascal\bgi\graph.pas $(MINGWDIR)\units
+#endif
+
+uninstall:
+	$(RM) $(LIBDIR)/$(GRX20ln)
+	$(RM) -r $(HEADERDIR)
+#ifeq ($(INCLUDE_GPC_SUPPORT),y)
+#	$(RM) $(MINGWDIR)\units\grx.pas
+#	$(RM) $(MINGWDIR)\units\graph.pas
+#endif
+
+install-bin: $(UTILPC) $(UTILPW)
+	install -m 755 $(UTILPC) $(UTILPW) $(EXECDIR)
+
+uninstall-bin:
+	for i in $(UTILPC) $(UTILPW); do \
+	fn=`basename $$i`; \
+	$(RM) $(EXECDIR)/$$fn; done
+
+ifdef GRX_DEFAULT_FONT_PATH
+install-fonts:
+	$(INSTALL) -m 755 -d  $(GRX_DEFAULT_FONT_PATH)
+	$(INSTALL) -m 644 ../fonts/* $(GRX_DEFAULT_FONT_PATH)
+uninstall-fonts:
+	$(RM) -r $(GRX_DEFAULT_FONT_PATH)
+endif
+
+dep:
+	$(RM) depend.tmp
+	$(CC) -MM $(CCOPT) $(INCDIR) $(ALL_O:.o=.c) >depend.tmp
+	sed 's#^.*: \(.*\)\.c#\1.o: \1.c#g'   <depend.tmp >depend.w32
+	$(RM) depend.tmp
+
+depend.b: depend.new
+	sed "s#\.o:#.obj:#g" <depend.new >depend.b
+	sed "s#\.o:#.asm:#g" <depend.new >>depend.b
+
+$(GRX20ST): $(TAG) $(ALL_O)
+	$(RM) $(GRX20ST)
+	$(AR) -r $(GRX20ST) $(ALL_O)
+	$(RANLIB) $(GRX20ST)
+
+ifeq ($(INCLUDE_SHARED_SUPPORT),y)
+libsh: $(GRX20SH)
+else
+libsh:
+endif
+
+$(GRX20SH): $(TAG) $(ALL_O)
+	$(RM) $(GRX20SH)
+	$(CC) $(CCOPT) -shared -Wl,--export-all \
+	-Wl,--output-def=../lib/win32/out.def \
+	-Wl,--out-implib=$(GRX20IMP) -o $(GRX20SH) $(ALL_O) \
+        $(ADDON_LIBS)
+	cp $(GRX20SH) ../test
+
+$(UTILPC): ../bin/%.exe : utilprog/%.o $(GRX20ST)
+ifeq ($(FDRIVER), X11)
+	$(CC)  -o $@ utilprog/$*.o $(GRX20ST) $(ADDON_LIBS) $(X11LIBS)
+else
+	$(CC)  -o $@ utilprog/$*.o $(GRX20ST) $(ADDON_LIBS)
+endif
+$(UTILPW): ../bin/%.exe : utilprog/%.o $(GRX20ST)
+	$(CC) $(LDFLAGS)  -o $@ utilprog/$*.o $(GRX20ST) $(ADDON_LIBS)
+
+$(TAG):
+	$(MAKE) -f $(MAKEFILE) clean
+	$(RM) $(SYSTEM_TAG_PREFIX).*
+ifeq ($(TARGET),native)
+	echo WIN32_GCC_i386_STATIC_CYGWIN > $(TAG)
+else
+	echo WIN32_GCC_i386_STATIC_CYGMING > $(TAG)
+endif
+
+$(ALL_O): $(TAG)
+
+$(ALL_O:.o=.i) : %.i : %.c
+	$(CC) -E $(CCOPT) $(INCDIR) $*.c > $*.i
+
+$(ALL_O:.o=.dm) : %.dm : %.c
+	$(CC) -dM -E $(CCOPT) $(INCDIR) $*.c > $*.dm
+
+.c.s:
+	$(CC) -S $(CCOPT) $(INCDIR) $*.c -o $*.s
+
+.c.o:
+	$(CC) -c $(CCOPT) $(INCDIR) $*.c -o $*.o
+
+#include depend.w32
diff --binary -Nru3 grx246/src/mouse/input.h tgrx246/src/mouse/input.h
--- grx246/src/mouse/input.h	2001-04-01 03:27:02.000000000 +0200
+++ tgrx246/src/mouse/input.h	2004-01-23 16:28:09.049281600 +0100
@@ -113,7 +113,7 @@
 #endif
 #endif
 
-#ifdef __WIN32__
+#if defined (__WIN32__) || defined (W32NATIVE_DRIVER)
 #include <time.h>
 #define real_time(tv) do {                                                  \
 	(tv) = clock();                                                     \
diff --binary -Nru3 grx246/src/utils/dbgprint.c tgrx246/src/utils/dbgprint.c
--- grx246/src/utils/dbgprint.c	2003-06-11 00:39:30.000000000 +0200
+++ tgrx246/src/utils/dbgprint.c	2004-02-08 14:07:31.173049600 +0100
@@ -19,6 +19,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
+#if defined(__CYGWIN32__)||defined(__MINGW32__)
+#include <w32api/windows.h>
+#endif
 
 #include "grxdebug.h"
 
@@ -28,18 +31,18 @@
 
 char *_GR_debug_file;
 int   _GR_debug_line;
-#ifdef __GNUC__
+#if defined(__GNUC__)||defined(__CYGWIN32__)||defined(__MINGW32__)
 char *_GR_debug_function;
 # endif
 int   _GR_debug_flags = DEBUG-0;
 
 void _GR_debug_printf(char *fmt,...)
 {
-	FILE *dfp = NULL;
+       FILE *dfp = NULL;
 	va_list ap;
 	dfp = fopen(DBG_LOGFILE,"at");
 	if(!dfp) return;
-#ifdef __GNUC__
+#if defined(__GNUC__)||defined(__CYGWIN32__)||defined(__MINGW32__)
 	fprintf(dfp,"%s|%s|%d: ",
 		_GR_debug_file, _GR_debug_function, _GR_debug_line);
 #else
diff --binary -Nru3 grx246/src/vdrivers/vd_win32.c tgrx246/src/vdrivers/vd_win32.c
--- grx246/src/vdrivers/vd_win32.c	2003-04-14 21:49:54.000000000 +0200
+++ tgrx246/src/vdrivers/vd_win32.c	2004-02-08 14:40:29.337510400 +0100
@@ -95,7 +95,7 @@
 static int maxScreenWidth, maxScreenHeight;
 static int maxWindowWidth, maxWindowHeight;
 
-HANDLE windowThread = INVALID_HANDLE_VALUE;
+static HANDLE windowThread = INVALID_HANDLE_VALUE;
 static HANDLE mainThread   = INVALID_HANDLE_VALUE;
 
 static volatile int isWindowThreadRunning = 0;
@@ -348,11 +348,7 @@
 static void reset(void)
 {
     isMainWaitingTermination = 1;
-    PostMessage(hGRXWnd, WM_CLOSE, 0, 0);
-
-    while (isWindowThreadRunning == 1)
-	Sleep(1); 
-
+    TerminateThread(windowThread,0);
     isMainWaitingTermination = 0;
     DeleteCriticalSection(&_csEventQueue);
 
diff --binary -Nru3 grx246/src/vdrivers/vtable.c tgrx246/src/vdrivers/vtable.c
--- grx246/src/vdrivers/vtable.c	2003-04-02 21:36:34.000000000 +0200
+++ tgrx246/src/vdrivers/vtable.c	2004-01-23 16:34:59.669724800 +0100
@@ -45,7 +45,7 @@
     &_GrVideoDriverLINUXFB,
 #endif
 #endif
-#ifdef __WIN32__
+#if defined (__WIN32__)|| defined (W32NATIVE_DRIVER)
     &_GrVideoDriverWIN32,
 #endif
     &_GrDriverMEM,
diff --binary -Nru3 grx246/test/bgi/makefile.cyg tgrx246/test/bgi/makefile.cyg
--- grx246/test/bgi/makefile.cyg	1970-01-01 01:00:00.000000000 +0100
+++ tgrx246/test/bgi/makefile.cyg	2004-01-24 10:35:40.631886400 +0100
@@ -0,0 +1,44 @@
+#
+# GRX test programs makefile for Mingw
+# Uses GNU make.
+#
+.SUFFIXES: .exe
+.PHONY: clean install uninstall
+
+
+include ../../makedefs.grx
+
+INCDIR=  -I../../include
+GRX20 = ../../lib/$(GRX_LIB_SUBDIR)/libgrx20.a
+
+LIBS= $(GRX20) $(ADDON_LIBS)
+
+PROGS=                  \
+	bgilink.exe     \
+	bccbgi.exe      \
+	colortst.exe    \
+	small.exe       \
+	tellipse.exe    \
+	tfill.exe       \
+	tmodes.exe      \
+	tpoly.exe       \
+	ttext.exe
+
+all: 	$(PROGS) \
+
+$(PROGS): %.exe : %.o $(GRX20)
+	$(CC) $(LDOPT) -o $*.exe $*.o $(LIBS) -lm -mwindows -mconsole
+
+.c.o:
+	$(CC) -c $(CCOPT) $(INCDIR) $*.c -o $*.o
+
+.c.s:
+	$(CC) -S $(CCOPT) $(INCDIR) $*.c
+
+clean:
+	rm -f *.o *.exe
+
+#depend.new:
+#	$(CC) -MM $(CCOPT) $(INCDIR) $(PROGS:.exe=.c) >depend.new
+
+#include depend.gnu
diff --binary -Nru3 grx246/test/demogrx.c tgrx246/test/demogrx.c
--- grx246/test/demogrx.c	2003-02-26 23:37:04.000000000 +0100
+++ tgrx246/test/demogrx.c	2004-01-22 21:13:22.667368000 +0100
@@ -365,6 +365,8 @@
 	strcpy(sys, "WAT");
     if (nsys == GRX_VERSION_GCC_386_WIN32)
 	strcpy(sys, "W32");
+    if (nsys == GRX_VERSION_GCC_386_CYG32)
+        strcpy(sys, "C32");
 
     sprintf(aux, "Version:%x System:%s", GrGetLibraryVersion(), sys);
     GrDrawString(aux, strlen(aux), 0 + x, 0 + y, &grt_centered);
@@ -402,7 +404,7 @@
 	for (i = 0; i < NDEMOS; i++) {
 	    if (ev->p1 == ptable[i].cid) {
 		gfaz_fin();
-#if defined(__MSDOS__) || defined(__WIN32__)
+#if (defined(__MSDOS__) || defined(__WIN32__))&& !defined(__CYGWIN32__)
 		if (ev->p1 == ID_MODETEST)
 		    strcpy(nprog, "..\\bin\\");
 		else
diff --binary -Nru3 grx246/test/keys.c tgrx246/test/keys.c
--- grx246/test/keys.c	2003-02-26 23:38:02.000000000 +0100
+++ tgrx246/test/keys.c	2004-02-08 12:29:42.864836800 +0100
@@ -358,7 +358,9 @@
 #if (GRX_VERSION_API-0) >= 0x0229
   if ( GrGetLibrarySystem() == GRX_VERSION_GENERIC_X11)
     GrSetMode(GR_320_200_graphics);
-#elif (GRX_VERSION == GRX_VERSION_GENERIC_X11)
+#elif (GRX_VERSION == GRX_VERSION_GENERIC_X11) \
+    ||(GRX_VERSION == GRX_VERSION_GCC_386_WIN32) \
+    ||(GRX_VERSION == GRX_VERSION_GCC_386_CYG32)
   GrSetMode(GR_320_200_graphics);
 #endif
 
diff --binary -Nru3 grx246/test/makefile.cyg tgrx246/test/makefile.cyg
--- grx246/test/makefile.cyg	1970-01-01 01:00:00.000000000 +0100
+++ tgrx246/test/makefile.cyg	2004-02-08 14:46:32.529755200 +0100
@@ -0,0 +1,81 @@
+#
+# GRX test programs makefile for Cygwin
+# Uses GNU make.
+#
+.SUFFIXES: .exe
+.PHONY: clean install uninstall
+
+
+include ../makedefs.grx
+
+INCDIR=  -I../include
+ifeq ($(INCLUDE_SHARED_SUPPORT),y)
+GRX20sn    = $(DLLPREFIX)GRX20.dll
+GRX20   = ../lib/$(GRX_LIB_SUBDIR)/lib$(GRX20sn).a
+else
+GRX20 = ../lib/$(GRX_LIB_SUBDIR)/libgrx20.a
+endif
+
+LIBS= $(GRX20) $(ADDON_LIBS) -lgdi32 -lm
+
+
+PROGS=  arctest.exe     \
+	bb1test.exe     \
+	blittest.exe    \
+	circtest.exe    \
+	cliptest.exe    \
+	colorops.exe    \
+	curstest.exe    \
+	fontdemo.exe    \
+	fonttest.exe    \
+	imgtest.exe     \
+	jpgtest.exe     \
+	life.exe        \
+	linetest.exe    \
+	mousetst.exe    \
+	pcirctst.exe    \
+	pnmtest.exe     \
+	pngtest.exe     \
+	polytest.exe    \
+	rgbtest.exe     \
+	sbctest.exe     \
+	scroltst.exe    \
+	textpatt.exe    \
+	winclip.exe     \
+	wintest.exe
+
+all: 	$(PROGS) \
+	demogrx.exe \
+	keys.exe \
+	speedtst.exe \
+	memtest.exe
+
+
+demogrx.exe: demogrx.o gfaz.o $(GRX20)
+	$(CC) $(LDOPT) -o demogrx.exe demogrx.o gfaz.o $(LIBS)
+
+keys.exe: keys.o $(GRX20)
+	$(CC) $(LDOPT) -o keys.exe keys.o $(LIBS) -mconsole
+
+speedtst.exe: speedtst.o $(GRX20)
+	$(CC) $(LDOPT) -o speedtst.exe speedtst.o $(LIBS) -mconsole
+
+memtest.exe: memtest.o $(GRX20)
+	$(CC) $(LDOPT) -o memtest.exe memtest.o $(LIBS) -mconsole
+
+$(PROGS): %.exe : %.o $(GRX20)
+	$(CC) $(LDOPT) -o $*.exe $*.o $(LIBS) -mconsole
+
+.c.o:
+	$(CC) -c $(CCOPT) $(INCDIR) $*.c -o $*.o
+
+.c.s:
+	$(CC) -S $(CCOPT) $(INCDIR) $*.c
+
+clean:
+	rm -f *.o *.exe *.stackdump output.png p.jpg pgray.jpg
+
+depend.new:
+	$(CC) -MM $(CCOPT) $(INCDIR) $(PROGS:.exe=.c) >depend.new
+
+include depend.gnu
Files grx246/test/output.ppm and tgrx246/test/output.ppm differ
Files grx246/test/prueba.pbm and tgrx246/test/prueba.pbm differ
diff --binary -Nru3 grx246/test/prueba.pgm tgrx246/test/prueba.pgm
--- grx246/test/prueba.pgm	1970-01-01 01:00:00.000000000 +0100
+++ tgrx246/test/prueba.pgm	2004-02-08 14:21:39.312614400 +0100
@@ -0,0 +1,5 @@
+P5
+#TestPnm
+227 149
+255
+++,-..//00000000///..///........,,,++***********'(()*+,,//011232679;<=>>???>??@A=?AEKPSTXZZ]^_`_fffffeccbaaaa`]ZSTTSSSRRRRQPNNMMKKKJJIIIKKJJJKLMMLLNSVXYTUVUOE812220..--///..---+++++++++*)((.5;FOVYanwx|}u_LFJFFM^tq]OHMNN++,,-.//00000000//....//........,,+++***++++++++())*+,--//001232568:;<==>>===>?@<>AEILOPSTUXZ\]]dcdefeddbaaaa`]YTTSSSRRRRQQONNMMKKJJJIIIKJJJJKLMMLMNSWXYVWVUND923321/...///..---++++++++++)()-49BJRW^jsw{}~qZJEFFGKTg|taSLONN**+,--../////////.----./........,+++****++++++++**+,,--.///012224579;<;;;;;;;<=>=>@CGIKMKKNQUY[\`abcefeecbbba_\XRSSRRRQRQPPOOMMLKJJJIIIIJJIIJJKLNMMOTWYYZYYUMC93443110/////..---++++++++-,+)),15<DLQXclqw{~yjUGCCFHFHUk~}o_RMPPP)**+,---........--,,,,--........+++***)),,,,,,,,,,,--...../01121355799::9:899:<<>@ACEFHHFGJMRW[\__accdddcbbba_[WRRRRQQQQQPONNMLKJJJIIIHHIIHHIJKKNMMQUXYY\][ULA8455432100///..---,,,,,,,,..-+*+/29?FKOYdlrwysdRGCBFGC@HXeortodYPMRRR)))*+,,-,,,,,,,,,,++++,,--------++***))),,,,,,,,-----.....//012212456777667889:;@ABCDEFFEFHLQV[\_``bbbbbbabba^YTRQQQQPPQPONNMLKJJKJJJIIIIIIIHJJKNNOQVYZYY[ZSI>6155432110///..---,,,,,,,,...,**,.6;@DGP]ipuwpcUJEDDCBACGJZ]_\VROPSSS(())*+,,++++++++++*))*++++++++++****)))(++++++++---------../011111234555656788:<@AABCCDDDEGJNTX[^^``a`a`b`aa`\VQQQPPQPPPOONLLKJJJJJJIIIHIGHGHHJJNNOTXZZYWZ[UJ=6155431100///..------------..-+*,,359>BJ[ktyysg\PFEB??AA>;AEHHHHLOSSS''()**++**********))))**))))))))***)))((++++++++---,,,,,--./001101123333556689;;???@ABABCCDGJOTVZ\^_`bbb```a_[TOQQQPPPOONNNMLJJIJIIHIIHHHHGGHIIJNOPTXZ[ZZ`b]RE<85443100////..-----------,-.-+*+,/039=G]q~xpeUGC?>?A@=:;@DHHILOSSR''(()*++*********))(())*((((((((***))(((********,,,,,,,,--.//011/011222255667:;;===>?@@@BABCGKPRXY\_accd__``^YRNQQPPPOOONOMLKJIJIIIHIHHHHGGGGHIJNOQUX[[Zagkg\ODA444200/////..-----------+,..,++,+,06<H`w~wkYG@>=>????IMSUTSSUSSS)))*))))***)))((((((((()((((((((((())**+********)*+,,,,,,,,,-./0./01122222345678;<<==<<;?@BDHJMNRSWZ^abcacca\VRPPOONMMNNKLKKJIIIGGHGGGFFHGGHIJKKOPTZ[YZ_gnspkaTHE@9310/.//..-,++,,,,,,,,--------*.239LixmbZIB=<>CMVepwqlh_TSTU))))))))*)))((((''''((((((((((((((()))**********))*+,,++++++,-././/1122122234688::;<<<;;=?@DFIKLPRTWZ]`abcca\UQPPPONNNMMLLKJIJIHGHGGGFFFGGGGHJKLQQUZ\[^cmt{xrgZNFB=852/,..--,+++,,,,,,,,--------+-03<Ql}upj[UPQV]jtx~wrfYQRT)))))*)))))(('''''''&&&&((((((((''((())))))*****))*++++*****+,-..//011112222457899:;;;99;=>BEHJKNPPQVX\]abb`ZTPOPOMMMMMMKKJJJHGHGGGFFFEEFFFGHJLMTSU[\]bjv~{rdWIFB=:40+,,++**++++++++++,,,,,,,,,,.3@Wq~xsqqt~}l[OPR********))(('''''&&&&%%%'''''''''''''(((())))***()****))))))*+,-/01111111111245677899997;<>ADGIKMNNNQTXZ^`a^YSOMNNLKKLLLJJJIIHHGFFFFEEEDEFFGIKMNUSTY\`ho~{maPLFA<61-,+*)))*+********++++++++-++2C\umYLMQ++++****)))((''''''&&%%%'''''''''''''&&&'(())***()))))('(((()*,-.01111000000123456787776::=?DGJKNMMMORTWY[\ZVRMMMMLKJJKKJIJHHGGGFEEEDDDDDFGHKLOPTRTY^cmwshYTKC=932,+))((*+********++++++++-*)1C\ujUJLM,,,,++++***)))((((('&%%%&&&&&&&&''&&&%%%'''())**(())(('&))()*+,-//11100/0///01223456666478;>AEHILLLLNOQSTVXWSOMLLKJJIIJJIIIHGGFFEEDDDCCCFFHIKNQRSQTZbhsxmc\RHA<85/-*)'()*))))))))********+))0AYr{gRHHI,,,,++++++++**))*))('&&%&&&&&&&&&&&%%%$$&&'())**((((('&&))))*+--/001100////.//0132456544457:?BDFIJKLLMNNNQSTQNLLKKJIHHIIIIHHGFEEDDDCDCBBFGIJMPSURRV^gn{|sidZQIB<82/,(''(*(((((((())))))))*)*/=TnucODCB++++,,,+,,,+++**+**))'&&&&&&&&&&&&&%&$$#%&''()**(((('&&&****+,-.111110////.../00123444331258<@CDHIJKKKLKKMQRQMLKKJIHIHIJHHHGFFEEDDCDDCCCGGIKNQTVRSYbkt~wlh`XPG?921-)''()(((((((())))))))))*/;Qj}{q^LCA=+++,,,--.///.-,,--,+**))))**)(&&''''''((((()))**)))**+++**+,-/./1122210/0//..//0/0022110---/4:?CGHJLLJIGIJMNNMJHJJIIIHGGJIIHGFEEBHC>DDBGDIMQSSTTU\enu|vnfa^XMC:5.)'''&'''%%'''(((((()('))*7Pkzvk\NG?:+,,,---.//00/.----,,+*)))***)''%''''''(((())*****+*****+++,,-./0222221000/..../00011210/-,-/38=@EFHJKJIIFHIKLLLKJJIIHHGGIHHGFEDDAD@?CC?AFJNQRSTTT\gqyxrjfd^TKA;3-)('&''&&&'(((((()(((++)(3Njz~vk\NC<6----..//001110/...-,,+****+**)''''''''(())***++++++++***,-../012334432110/..../010000/...../159;?ACGHIHHHHHIJKLNKIJIHGGGGGFEEDEDFDBBFFCBHJOQRRTUT]hqy|wqnlh`XLE;3-)(&&&&&&'()((())))),,'&1Khy~}uk\N@83..///00001233211///.-,,,,,,,++*((((((()(**++,,,,--,,,+++///013345565542200/../002211//..0//00357>@CFGHHGJJKKLKKKJJIIHGFFEEEDDDDDGAADBDHGJMOQQSUWY_got{}zwutqjdXPE:2-*&&&&&&'))'''(((('()('2Kdsz{|tk\O?73000111112245553311000/...//.-,+*********,,,,--..........1213456677876533110000113332210022112345>@CFGHHGFHJJKKJJJJJHGGFFDDDDEDDDD<CH>>HJLMOPQSVY^cilqx~|zyyvrnb[PD:2-((''&&'')'&'''&&'"(-1<Pcmuvzzsi[O<5111223322346666554432321101210/.-,,,,,,,,---...////000111334567789999864433211233444544434444445579=@CDDCCDFGHIJJIJIIGFFEDDDEEEEEBBYcLCMPLNPQRTY^afkory~~~~|yumg\QF<3.+**))()((((((((('0:@IWcippsy||}~xqj[O<5123334434456777777765443333333100---.........//0000012545456779:::::9975454433445456778876666667746<AEHIJMKGFDFIKJJIHGFEEEEEFFFFEBNyfNSRLNPQRV[aekorsuz}~}vqg]RG=610.-,+**+++***)*4>JPW`gjomov{{|}wpi[OA9433444544567888888887655455554310..//////..///0000114567756679:;;;;::986566544566457999::66777887;>EKQUWY\WOFCCGJIIHGGGFFFFFFFEED>SuSRLMNOQSW^chmrspmkmzvndZNB;531/.,,,.---,,,-?JV[`gklpnpw|}}~{vqi[OF>95555557777889:;;<<;;;::977777766555444443321110022233467688;;<====<;9888655444552@=9?83?8:955<BCQQTWTNMR[\ac[OJNIIECEIHDFECBCDA?`y]kbNXPTY[XX_hcs|p^WX\hku{yumcXNHC888-)2642120.07DOVZbmroorwz|~~}ztqoh[QGFC555556898899:;;;=<;;;;:::::9888666665555432221002223356777::<<====<:9888665555666713>BENMOPORY\[ONPRNIIMRMNRUUX_^[SKIKIECMRI<>RfgiYXrfIV\SS]b_`eospdYWXY^_clonorwx{|~}yurprd[VPO?$522678<BIQW[erwsutvx{}}}|wrng[RJJI4445679:::;;;;;;<<<;;;<;=<;:989877778888443211002213356788:;<<=<=<;:988766666778B5;N^ippQTVY_ffbQPOPMJKOUNGJORUXHQZaa\OCB?=@GVdleTXNdrT]_WZdhcfoxqi`_`^[`^]_^\^aghjlnprsqpnmnquw~wnoua:05;=62:EGNVZhw{vywwvx{|||rle[TNMN334568:;<<<<<<<<===<<===?>=<:98877887899544321112132457889:;<<<<<<;:97877777789991HgnrqbGIKOW`_ZUUSRRRUWXRMLNMKJQSRRVaghNC=I_jcW[NWT]nb\U^hhbdrqjcbfie_hd``_^_cabccdgghkihhimorvwyur{zh?958:9:=CMWap{{}}{y{tkc[UOOQ2234579:<<<<<===>>=>???>?>=<::987778887755543221333346789:;<<=<<<;;98877887789::9>]tlcXEGHGJR[\XSSRRTW\]QQOMMOQS^^[VXaik[ahjf^YWUWQWRUg[P_f^^m|fa^_cfgglfa_^]`deeffgiklmnnmmmmmpkptnovxjM0/?IC;DSbqxkb\WOOQ11234578::;<==>>??>?@@?@?>>=<;;:998888766655432233235689::;<==<<<;:98866777789::?Skpc[UIHIHGLSTQKLLKOWYYQRNIKS[^QZbdc`YSXdnj\SU[S[LUNMtt[[WVey{ohb^\]airmga_][^cdddegilmhijkjihfqhjrrruuqVB98?GL_t¾}od]ZSST11112445789;<>>>?@??@@AA@???>===<<;:98886665443333335689:;<===<<;;:98766666678:9<ZfVMNMLGJKIJLLIHJIINVXTUSOKOX[XVXUPNSX[STVVVVVWSUQTRUojZS`txndic_\YY`ikebba^`dccbcdfhijklnnnmlojnrrz{jL<DTavùshb_[[Z11111223678:<>?@@@?@@AABBB@@@@@@??=<:9976766543333345689<;<===<<;;:9776655567899HmmNFJGHMRUROOLIJMMKPWYSPONPYa\POUZWUUUSVXYYWWVUZP\SSWUzr]\r}ncfa][[VOOTfbabcacgjifedfghjkkkkkkkktxofx||}naZz̾xlebaa`-./133335679;=??BAAABCDDC@>AEEA<A><=?>969754543176656678:;;<<<<;;:876689:34:816Cs]KIKIJOJMQQOMKKIIJNRTSSPOORX\ULSTUWWXXXWXXXYXYXXRQTROYhchswob`ecb^YSPPQbdc_`egckjklifglolgegmrtuttrnn{nxzpbsûvpnxsp+,.011224579;==?AAAABCDEBBDJPTQLE@<:;<:78644554211235678:;;<<<<;99886544877:87BP^NEHKHINKNQSRPNNMLKMPRSQQMPZ^VPPSTVWYXYXXWWXXXWVZUUYVOT_`dloi`ahca^WROOPXafc`cfhhhjmjfhlomjjlpstsqps|~ztnmkirvMxȸ*+,-/0114568:<=>@AABCDDEBELXbhgdVNE><;:786334554/0245677:;;<<<<;45664420477429HUMFDKMHHLLOSUTSRTQOMMOQQORMTb^OLTTUVXXXYXXWWXVVUTWUW[YRSZWYahidbda_\VPMMNLZfe``gmfeimlhhkmmmprtusqrst}yipyadDv**+,-.0034579;<=?@ACDEEECJWft||{rh\QKD>:<843234334567766::;<<<<;7776656457635ALSKJLQPJILLORUUUVVVSOMNOOOQRY]XLMUUTVWXXWWXWXWUTSRRQTZZVX^QRV`iha[\[WTPMNPJVac`aiqccgnnjhjkmoruvusovxsrzyqkn^{>KyƸ,,++,-/0234579;<?ABDEFFEEN^qukbYNHD?94120023356677::;<<<<;<;9644456546ANRNOOQRQMMPKNQTTTVWXUQOOOPPPY\SMOSSUUWXXXWWXXWVUSRQQPRUWX\`aZWZdg_UVUTRPPRTPTZ^adjpbbfnomjkikorvvtrszyrpxzrhguR8pû1/.,,-./123568::?@BEEGFFGRdx|sibWPG>85311112568:::;<<==<;:743211500;KSOHNOQQPOQRLNQRSUVXXUSRRSRQR][MJUZRVVWWXXWVXWXWVTSRUSSSTVY\sla\]`]UQRQQPQTWXUV\adgkcbfnrommijnruvutwxuuzwivqq\sƼ531.--./0123579:=?BEFGFFFSg}~ul_RJC@>;965568::;;=<==<:<>ABB@?A88FSQKGOPPQRRRPMOQSSTWYWVTTUVTSY[WPRYZSUVWXXWVVWXXWWUTSVUTRSUVUiqsi_[WTRQRPPRUX\YZ`cccfecfnsrppjkmquvvvxvv{|umyum{jqpos8530.../00235789=?BEFGGEGTi~teZRMJHE@:7678:;<====<?EMV[]\ZTIIV]SKLQRSRSTQLNPRSSUWZVUUVWWWU_WRW\\XVVVWXXWVVWXXXWVTTSTSSTVURQi|xgYRPSRQQPQTV\Z^ee`_cgcenssqrllmpuwxyvy~wqs{|nuqwoom|9875320/../0258:<?BDEFHJFO`y|ocYRQQNF=77:8;>=;<?DN]ikptm``^`aZOIJNOQSSSRRNOQSUWXXXXYXVVXZb]W_xz`WXYXTSTVWXXURQSVUVVWWVUU]Uc|q\YMPQQRQRUWW\ipgXWaeehoqnlntrposwwwxwy|~|zyx||jiuttp:9864321///01479;>ACDEGIGN_v}pe_YWUOG@=<7<?>;>HQbpxz|~wkggc\SNNOKJLMMNNNLOSXZ\\\^\\^bcba`a`XRVgxb[RRW[XTZ[\YURRSTTVUUTSRWSZknf\KRRRRQQSTX[gnh[Y`ffjoqnlnvvuuvwxwqw~}xuuws{{ptznlc<;:8643200/01468:=@BCCFGHM[punc`\WQIA<29>>>EWdv~ui`fcVNPQOOOOPRSTUQTY\_^\[XUTZaeb^]UTWRLUekcZVVXXVTVWXURQRSUUVWWVVSZXZktbOSSSRRQQQVYbkh^Z^dcgnnljlvy|{xuuvpv}}ywy|yy~|x~neRn?><;976521111357:<?AABCEIKWlzoia[WOE<48>CHUdpz{uncYR`dYSWUNKJKLNPTV\]]]\ZWUONOT[]YVVMJV`\RMdikcWOSZVVVUSRQPUVWY[\]]ThgSdvf^VTSSSSRQUV]ee^YY``dikgfgtxyrqtvxyxw|}}|zwpaG]BA@?=;9843223456:<>@@@BDIJSg}vkd_XOGGFHNYcknnqqlf_VOYcf\Y^]SSSRUWZ]_`^\ZVUTSRTWYYXWVPUVPOVZWYbki^UVY^[WSRQRRZ[[\[\\[Ur{YYlclXUSSTUTSRSX^_ZVT]]ahjgdfuy}qpszywv{{zvlnbDTwEDCA@>;;76544467:=@@@@BCHHPd{}uqld^a\Z^fjieccdc`\VRhhaVV[\U[[\\^`ab[XWTSTUVX[]\YVVWOZZOKSXUTV[agd^VTQNNQW[]]]\ZYVTSRkcR`\q^ZTQTUVUQSUWWVTSZ[_fiffhw{vsxzzy{q{{|vvcFPlGFECA??>:9765667;=?AAABCGEOc{|wpkfefgc`_^`a`\YXmdZWXZWTSSSSRQPORRRSSUWX\[ZXWVTSSRRSXYSLTQQYcea\USQRV\^_[ZYXUTQQNYnU\Wmg`WRSUUTRUVURQRSTUZaedcfyzyv{{}|u_FMbIHFDB@??<;876678;>@AAACCEDNc|olgdb``````a^ZWVlaZ`eaYT\\[YWSPNOPRTUUUUa\VVYYUQVONUTOR]RTUWW[`eokea_[WTVVVWVVUUMJ|u[`WineYSSTTRSVWRNOSUNNT\`_`axv}zv{}~|}r\FK[IJHHFEDC?>=;:::;>?ABDDDFIHQdytba`__```_]bV\]Lehda^_^\Z\Y\dbUNQPQRPPQTWaYRTZ\XQPPQOOQRSNQSTSSSUUWZYVUUWXVTVYZVRJNprViQdkf_WTSSUUSQRRSSROQSUUWWYzz~z|zyaKGeJIIGGFED@?>=<<<<=>@BDDEEIHQdx}i`^^^^^__^Z_W\ZOkca_\[YYX`WV_bYQPOPRRRTX[^[WVWWTRUSSSVVTRSUUTROPQRTUTSSTUTUWWVUVU[F^Yaq__pmf^XTTSUTRSTTUSOQSTUUXZ}xyxt|t|wvaPNhKJJHGFEECBA?????>@ACEEEEHIRdvo]`_^_^^__^Y]\\VTra`^\XVWWbUOYb^SONPRTUX\_SUVVVWXZOMLMPPMJ`_\YTRQRTRQQQRSRPTWVSRUY\LmX^ahqqnke_XTQQPOPRSRQOPQRRTX[q|wx}nz{mtvl\SSkKKJIHHGGEDCBBBBB@ACEFFFFGIRctype\aaaaa`a``Z\`ZOXt`a_\YXY[^SLT\[UPPRTWXZ^`SSUVWXXZRTTSSTVVdb`[USTTWTPPQSRPRTUTRRUWUWxcSPavyk]QIRQPQRRQPOPPPPSW[cuwxuvdtiotgYWYoKKJJIHHHFEEEDEEDBCDFGGGGFGQ`oy|rssqle`_bccccbbbc\\bVK[naa`_]\^_WQOQTTRSSTWXXY[]\YWWXXTQOSUROPW^]\ZUQPQSVSQRVXWUYVRQSUUTXU[aQ\VXVYahmnnnXWSSSSRQOOOPOQUXavxxxxzz|girl`bfyJJJIIHHHGGFEEFFGDDFFGGGHGHOZfoy}wrlhliijfa_adeeeedddc`[aSK`e_][[]`_^QQQQPPQSTWXYXXYYXUTX\^[WQUVSPQX_XXWUSRSURQSW\^^]`YSQTUURUSObTcUORTWWVROL]YTPNNNMOPQOOORUfzxz|wigp{stwŹIIIIHHHHGGFFFGGHEEGGHHHIHGKS[bkty{~ztojfac_afe``cddeeeddd`aZ_PMe[YUQT[^]ZQSSRPQRRRUWXWWWXSTY[]^^_`__`a`aaWWXWVUVWQUY\^]^_c_YURRSSOW_dTSZZTVXXXXVVd^VOLKLLOPQPOOPQ_vwskelżÿIHHHHHGGHGGFFGHHFFGIHHHHJHIOTYblqsw|~|xtpnkhdXUYcfbabbccdcccc]aZ]OPjWTNJNV\ZTSTTRSTSQPRVVVVWW[_b_ZWWXYUSV[ZRLQTUVSSSTUY^`]ZYZdd_WQNRURUbYVF]YRSSSSRQRqi_VQQRRNPQQOMNOQmv|qkciý¼HHHHHHHHFFFGGHHHHHHIIJJJHHHJMRVYbhmpu}~zttwpcSRV]_]bjcbabdedb[YVTPQZeRYQQ_XMTORTSQRSTTUURPS[a^\YVTSSSTPQWXTNMWPNRRNOVYZ\]YWUUYWWoAJcMN\d\QQX]]YSPRVVSyq[OQPJMHIIJLOQROXp~miidxƽHHHHHHHHFFFGGHHHHHHIIJJJKJJJLORTZ`fipywsw|sdOJLU\]`dbaacdca`WURPNNWbb_VT\\QKPSUUTTTTUSRSW[]^UTTTVWXZWSSWVQKJOY\RNRTP`_][YZ\_TZWccORCU_d]TTWZWUQQTVWTzpYNSTPSONNNNMMLQXn~miifw~zy|ssruw|HHHHHHHHFFFGGHHHHHHIIJJJMLKJKLNORW]bkv}~|w~xeUONT\___aabddc_\TQNMLMU_`XWZ`h`KQRTVVUTTTPOV`c^XVVUTSSTUVSSVVQLLSZ^_ab[T[YYYXXXZS^W\cPOZ_`[VUUTQPPRTVVUxmWLVZWZ[ZZXVSONRVi{~{lgiirysnnorvwspfimt{GGGGGGGGFFFGGHHHHHHIIJJJLLKJJJKLOTY^gt{{xgd`]^____cbdeea]YVRNMMMT]ZT\abnmRROPTVWTTQQS[ab[TWWVUTTSSRQRUURRVaQVssbaSUXZZWQLRWSct]e\[XVUTQONNPSTRSVqgTNZ_Z\__`_\XURQTdx|vjdgklha`cfkpqoorv|GGGGGGGGFFFGGHHHHHHIIJJJJJJJJKLLNQTYdpvu~sdgjkf_]_`cdegfb\WWRNMMMRYd^dc[fpcYQLQVTSUOSY]^[VRUUWY[\]^VUX[ZX\aaYe~yhe\[[[[XRMPMUuxt_e`ZTSUUROONPSRNPWhaSQ^aZYXYZ[[XVUOP`t|tkdhmf[W]aflpsvx~FFFFFFFFFFFGGHHHHHHIIJJJIIJKKLMMMOPT_lrpw}oa_fke][^adcdeda[VUPLLMMRVga`[T_thYNPSTSUPV]]YUTU\\]^^]]\[[^`][aiZq~ysi^g_VQPRRQTMdgkXXh\TSWWUTPMORNJQ\b_VS]^WXVVWZZ[ZZPMZn~|rnfipcTUagnsvy}õGGGGGGGGGGGGGHHHHHHIIJJJJKKLLLLLMNOT_mrqurd[`gc^^_^aabbb^YUTNKMOQUZ]\UUWYi~hUTUSSWTX[ZWUXZ_^\ZWURQVY[\ZYblivlnfVdZNFGLOPTRos_]QVoaUSUSSUQMMOLITdbbYU[ZVYYXYYZ[[[TMTew|ymnegn\LS`jt{~ıFGFGFGFGFGFGGHHHHHHIIJJJLMMMMLKJNNOUbpwtyyj^bgccca\_____\WTTNLOSUZ_WZSW\PSot]VVSSXWYYXWX[_VUTTTRQPLOTVUVbnvqpnbT]UKGILLLLNkSXOM]pbTQQPPSPLJMJIWjce[UYXV\YXWUUVVVYMP`qxugjacjWFQ[hwGGGGGGGGHHHHHHHHGHIHHIKMNMLMNMLKMLPYgu~nd`dgc_`^]\ZZWTQJSOKW^XUXXWWXZWTYpu`SX]WShT\^ViSUXWNRVVLMXMRYP{W}~zuph^UYYTJDFJLLM\TNRR`fe^UPQQQSOGBGS^bkbWSVZ[\YZZYXXXYZMUSr}xqlcdctLAN`o}yGGGGGGGGHHHHHHHHGIJJIIKMNLKKKMMMMNR\jxzphkmid`\\ZZZWTROQLOXVRZTUUTVXYWWajeYSSX[kU]_YhSQRVXWTTVPPPdE]iMzwobZZQYZPB<;;BPjaQQZrba\TORUTWSPOQV\bf_VSVZ[[YZYXYXXYZMTSq}{vpjcgigGAOan{yeTHHHHHHHHHHHHHHHHHJLLKJJLLLKKMORSSTZer~siikjfb[ZYZZYUSQONW_TKVTTVWVVXZVU`kcQO\^jW]`^l]TNO[WRPZR_SQZuc{|tnmf[V\PVWRLHB><G]UIQ^y[^\XUZ]^^[]a_[_h`[UTVZZZYYYXYXXY[NPQn}xtohfjpSBBRcoz~~tXF8IIIIIIIIIIIIIIIIHJLLKIJJJMQTUWZ[]`gozunjgcaZZYZZYVTMQQZf_NLTUX[YUVYWT]kfWU`XaVY]brpf[MWTZRV`BXR]hyn\_b_[YXXTSSXdlf[NQcglunuRY][[^a`a\^d_ZamZWTUXYZYYYZYXXYY\PMOizuokeglrB?HXfqz|~ynVH=IIIIIIIIIIIIIIIIGHKKJIJLLS[bedeegkqw~zrt||sia\ZZZ[[ZWULTOPfpbRRQU[[VUXVY^cc_^]R[WWX`s|zrTURhZQQaUU^LNGZ`XU[YPSXblywY]ui[RZ__[YYV\WVXVU_nVUTUXYZZYYYXXXXY\SJNb~woigchlj:@N]irz}wi^UJJJJJJJJJJJJJJJJHIJJIJNOU^hpqonmnrw{~nY_hprqkbY]\\[\[WTOVKD]xvhSNNVYVUYTZ\Y\c`YTYZVTZkw|{\\Ok[RWJJv^YV@I\bWQUSKTi||}~ffuqjfSR^gjf]YVR\ZWTV[fnUUUVWXZZYYYXXWXY[UIMX}ulfdckhX;AP]hqz}wphKKKKKKKKJJJJJJJJKKKJJMQUbjuzyusstw|hQTUYckjb`^^]][WURVKG\sxubTMRWUUZTWYX]a^UWVZWVZ^fnxfqUgZbXORgWVCZY^`[TPW_m|}xxy}sq]QUTbgnnf\XXWX]]X[digVVVVWWZ[YYYXXWXYXXJMQ}yskeefndC>@NWeow|}}~~|smfKKKKKKKKJJJJJJJJLLLKKOUZms{}zvtuy|reUP]osmb`^^][WTRURSbjmut`RSWTUZXVW]baZUYTXWZ\TWcvudh^z^n\OZj_^d_Ud|z|}xxkgVQVQXbgf]UTXZQ\^W[ffZVWWVVXZ[ZYYXYXXYWZJMMyxrkfiipa6A?JQcmu{~{{{|~vnd^WHJLLKKKMNKIIMONLNLKMMO\lsw|~|wrnwzc\i}j`[\\XVYTP[S]i`ssj]TSWXWTUY][WVYSUVXYYYYXhvmYWwyuyvjba\VYcu~|pcWUSRTYb_\ZXXZZ^\\]^]YVUWXWWWYZ[ZZYYYYY^TPGSm{qmlherkJ/6>DSZes|~||}yz{|}}ti^XGEBGJLLLKLMNLKLNONLQMKPV[fqty|ysnnqw~ſ{dsui`_a^YW[TYOT^Zm~r^OMUVSX[^\XUVW[ZXVVVWWX]hu{{|rnp}wo[WVYTLQ^sz{qd\WXXUTW^\ZYXY[]]\\]][WUUWXXVWYZ[ZZYYYYY\ZRKPpxrmihhn`D239>IUapy{zyzwxyz|}~~{xrj`UKFFFGGILLLLMNONMNOONLQMMV`hpvwzyqhfmu~ǽ|r[j~yhaca\Y]Y]ROTQYz{o[OSVTWbg]RQSSWVTTVY]`LRas{xrqgio{v`VX]^WS_plpv|~rdZXZ^_\XWZZXXXZ]^[[\\\ZWTVWXXVVXZZZZYYXYYY`SNJwztsmdelmTA;56=?O[itxxvuuuvxz{|}}zxwqmf^TMGDJMPEHJLKLMONNNOONMKKMU_ipuxxvphcfqz~{qfq~ujdc`^[[b^TQLF]t~jUQUTUlyjXSUTRQQQSVY\LPW`ddflquwzw\XXWVQSeuccgqyxjZXZ^dda\YYXXXXZ\]\\\]][WTVWXXVVWYZ[[ZYXYYXcUNH~xrpjadolMEI>;A=ITcouutsstuwxz{|}{wtrqlha[USSTSVZDEIJKKMOMNOONMMMJUckpsvxvofbfpz{urrqw}tmfb\\abWVYHG_nfWTTRUsybZ[ZWVUSQNMLSNNV_b`_dntt|vb^[ZZ\anw[WYcmmaWY]`a`_[Y[ZYYYZZ[]]]]^\XUWXYXWVXY[ZZYYXYYXaTMN}tmigchrdJIRHAC>EM[ipsssrsuvwyz{~}zvsqomgd]YWY[^[]]ADFHIJLNNOOONNPQSapuuuvtohbdn{»pmegmcf{rie`\`W^lVNQUX[^\URj{sbYXY[\\[XVTRBKYb_WUXWgsv{|q`aadkptvwXSS[cb]ZZ^]ZXXXW]]\[ZZYY\\\]][XUWXYXUUWY[[[YYYYYZZTM]smhceimpQGHOJDA=@GTajpqqqrttvxyy{yvsqnmlifa][]`b__^>ADFGIKMOPPONOTXcltuttrmfefku}ihack`gaqxsi^cZbtUUPOW]]\]W\a`[WWX\[\\\\^^DQ`cWKMV_irwyui\SW\bfhfcYVX^^[Z\Y^]WSVWV^]]\\\[[[[[\\ZVTXYYXVUWX[[[ZYYYY\SXPpxjkf`dlja<EFGJD<=<BLYdkopooqrtuvwxvtpommmljgdcdfgaa`>@CFFHJLQRRPORX^mqrpornf`dkrzzr\^UWaWfU_m{}rfm`cqHLNW^XMR`bXQSY[[]\[WTSTUVh]SRVURPgilosph_RUWWWWWU[Z]b_XW\Y^^WSVYX]]]]]]\\ZYYZ[YURXYYXVVWY[[[ZZYYY]N\R~ypgmgaemdP0DFBJD:?9>HT`hmonnoqrttuvuronmmlihggfgijcde<>@CDEIKLMNPT[dinrvtnfa_ciqzxh`YVVVX\Zdfj{xjauTOQQPQSUX[VY\XRQX_ZZXVTTWXUX]_\VMGW_horph]VVXXUTTTZYYYYWVVUWZZVWY^YZ[[\\[ZYZZZYXVUXXXXXXWWZZ[Z[ZYYZWX^vnrbdihn\.-4>FC<:==@GO[dilmmmoqtvwvsqqpolkljihiiigcfi8:>@BCGIKLMPV]fjmnnlea^]eks|}vg_XVVUVZ^ghiw~otOLRQPQRUWYWWWWVVVW[ZXVUSRQORWYZYVSOXagig\QRUWWWVWXZZYXVTRRSSVYYZ\]YZ[[\\[ZYZZZZXVUXXXXXXXWXXYYYYYX[TUs|lqkgbfqfG/225:;89<8DU`fgikklmprsuvvtrpqpmlljijjjiggjm369<>ADGJJMQW_gllje`[Z]_jpxxqe]WVUSTWcmnmw~yPMRRQQRTUVXTRUZZSMYWVVVTROOPRTWYZ[UY^_a`YRRUXXYXYYWWVTSQPPRRUY\]]\YZ[[[[[ZZ[[[YXVTWWWWWWWWWVWXXXWW[QX}udpejbftU/12/04767::Smzukhijkmpstuvxurqqqommlijkkjimpr/269<>BEGHKQYahkke]VUX_dns|una[VUVTSU^knozVRSRRQRSSTXURTYYSLTTSTVWVTTTTTUVWX__\XW[[WRUXYYWWXUUUVVVVUTTUY^`\ZYZ[[[[[Z[[\[ZXVUWVVVVVVVUVWXXXWXXRhxkflbfhnf@%1,.49968=Nlofgjlnruvwwyvsrrrqpnljklmkjpsv,0369<@CDFIOXafge_VPRYcjrx~}sl^XUVVTSTUdjlw|XQSSSSSSSSXWUUUTSRUUUUTTVXVWWVUSRQ[[XTTWVRORWYYYYZ[[\\]][\XXXZ]^ZVYZ[\[[[Z\\[\ZXVUWWWWWVVVUWXYXYYYUZ}uflcc`psO/,/+07845BQsuihknqvyzyyyvsqrrrqmlllmnmlsux*-1469=?BBEMX_bb^XQOT^iow|zqh[VTWXUUUVeklvy|sTNSTTTTUTTUVWVTRTWX\]ZTPSVUTVUUTQQRWZ[\ZTKMQV[[\]]\\\[ZYYX\[Z[\ZXUYZ[\[[[Z]]\\ZXVUUVVVVUUVUVWXYYYXUhtpdl`e_oh<,500352/9Ws}ojknsy||{zyvrpqrrrnmlmopomtwz)+.0248:@?CJU\^]\WTT]isx~wkbYTSXYWWXXgmmtvypr^PTSTUVUUUUPSUVTSSTU^fcYQQVSSTSTSSSSX\\]^XQSW[^^\\[YYXXWVVU\\][YXXXYZ[\[[[Z]]^]ZYVUUUUUUUUUSSVVWXWWXv~ojgfcejeM547133237Mspiinsy}}{yxuqpqqrrommoqqpovy|'),./246?>@IT[[Y]YX\gs|zsh^WSSW[YXXRbhgmqt}^\NP]SSUVVWWVMOSVXURON\ii^SSYUTSRQRTUXXWTVZ[X\_bb_ZWWXXYZ[\[][]^[XVY\YZ[\[[[Z]]^]\YWUUUUVUUUURRTUVWVU]|upfj^ibw\56=53334;Faodhlry||zxxtpopqrronnnpqqowz})('(+/357:?FLRWZVX]dnx~zsj_WWWVWVXXYOWennkqyr_TUXZXUUUVVWVVOQTXXVTPRKpfLYWSUTSRRRQQTY\[VW^df`[^\XWZ]ZZ[]_]]a`^[ZYXXZ[[]]^^^^]^^^[XTTSSTTTUUQUQKP[ZP}xph_^djuY=4:<5.234?\n`cgmsxyxwvspllpqqoqrqqpptw~)(((*.1369=DJOTWX[ait~~ytne]WXVWVVWXX[Z]eilqxrh\UVYXWUUUVVVVVOQTVXVSQRVlcPUTOWVUUUTTSUVVSQRX^h_XXZXY\YVT[fkhc]\\[ZZ[[Z[\\]^^]]]\\]ZWSSSSSSTTTPUQKPTV[}tjcbegjTJ=8769>39E\yx`[dglrwxwuuqolmqrrqsssqqrvy~~*+))+-/057;AGLPRVZblw}}~~yrle_YVWWVVVWXX\VV_jopp^\YXXXWVUUUVUVVVPQRTVVTQPda\WQTOTTTTSSRQWVSSTX\^a[XY[[]aYalvxqd[YYYYZ[]]Z[\\]]]]\[[[\YURRRRRRRRROUNLQJPn{pcagljgEB>;5127.;UxbPUbfjqvvutsommnqtutuuutsux|.-,,-./047:?CHLNRV^iu|{|}zxrjb\YVUVVVUVWWXTRVcmnhbTVXYXWWWUUUVUVVVRPOQUVTRPoYT\NTTQRSTSSRQTSRU[`a`Y[]\YY[^s~saXVXXXYZ[\][\\]]]]]\\[\\ZUSQRPQQQPPOTLLPDQ~wmccimidLD>>=72./@`oOGQ^ekpuutsrmlnpsuwxvvvutvz~2211112278;?CGJLORZdoz|zz||vtojb[WVUTVVVVWXYYVU[dgb[XTVXXVUVXUUUVVVVVTQMORUURVwZR[LPTRSTTVUUURQRX]`^Z[`a[WYclyeVRXaZZYYYZZZZ[\]]]\\]]\\][VTPPPOPONNNOKLLG[olhijieaKEA?=99<HXptTBEQZfjptutsrmmprtvxyvwwvvx|77777676:;>ADGJKORW_ju}}wtsuwyzytpmfa[WVVVVWWWWXZ[Zc^[\XTSTXXXWUUVYUUUVVWVVUPKKPUVS\wfVZNHQPPPQRSTUZYZ]`_[X\_^\apnXMRY]\\[[ZZZYZ[[\]]\\[^]\]]ZVTOOONNMLLMJKJITmmlkigebaCDB://@Ss|mR>;CPYfjquutrrnpsuuuwxyyzyy{;<<===<<>?@CFIKKQRTZblv|yqljkmnonjgd]ZWVWXWXXXXYZ[\\e\TRRPSVYXWVVVUVUUUWVWWWVPJIPUUSXmq^[UFPSRQPRTWXb`_`_^\[[\Z^kz}YROS]b]U\\[[[[[[[\\]]\\[\[\\]ZVSNONMLKKJNFLIEdxokgdcddeDB=62>\w|zyWG:7:>JXgkruvssrpsvwutuw{}|}}~=???AA@@@BCEHILMPPQT[fouxz|ytkfcbceeda][WVUVXZZXYYYYZ\]]^UMPSUVWXVVVXWUSUVUVVWWWWOHHOUVTP`we]]HS][YYY\ad`^\YYY\^_]Z_jm\FHOX\[Z]_[[[[[]]^\\]]]\[[[Z[[[XURMNMLKKKILCLHBnqskc_bfggK>36GenmwmU:34;;9DUglrvvusrsuxxustv~EEEEEEEEHIIJKMNNTSSTX]bgkmppmg_Y[YWUTSTTUUVVVWWWZ_WP[bbdZTNMRVVTXXXXXWUVVVVVVVVVRSMGHPTSQSX_eaUKid`_bca]Y[^^[YZ\a\TNKNSWTW[]^^]^[[[\\\[[WXYZ\\\]_\[\^\XTMMMKIHGFLH>A`k``__`bdgN<7Pyk\VQE;6;87::BT`lvxvvvtvwyxwwyz~}rHHHHHHHHIJJLMNOPTSSSVZ^`aceeb]WTTROMMMOPTSUUVWXXX_YV^b`aXTPNQTVUWXXXWWVVVUUUVVVVSSMFGOTSTPQXaijhb]YX[\YV[\]\[\^_ZVQLKNSVYZ]]\[[^[[[\[[[\Z[\]]]\\\]]]\XSOMMLJIGFFCBCMdxr_]_abccdeST^ylbUJE>725;869:ATalwywwwuwxyywwyz~~{qhNNNNNNNNLMNOPQRQVUTTUVXXYZ[[YVRQOMKHGIKKPPRTUWYZX_\[dd[YVTQOPSVWWWWXWVVVVUUVVVVVUSNFFMRTWROQXafiYUSUY^^^^\YXZ\]]QPLJJMQS[\^\[Z[][[[[[\[\[\]]]\[ZZ\^^YQLJLLKIHFEE??ETdhbYZ]`ceeddex{\BDC@:4324:8599AScny{xyyxz{zzxxy{~~nf_RRRRRRRRPQQRSTTTUVVXWVVVXXXXWUTTROKHFFHIJMNPSUWYZ]Z^jhZTVVTRPQUWVVWXWWWUUVVVVVVVVSMFEIOTURQQSVWXXVTVZ]``]ZWXYZWTMLKLLMOPXZ\]\\\]\\\\\\\]Z[[\[ZYYZ]^[SLIIKJIHGEDDE>AR^\[^[]_bddefxsP316;<9677397599@Rdoy{z{{z{}|{yy{}~ujc^TTTTTTTTTTTTUVVVVWXYYYXWZYYXXXXYVSNJFDDDFHJKNQSTXWT]ppb\YWWTRSUVVVWXXWWVVVVVVVVVVSMHEGMSPRSTTVXY][YWXXXW[ZZ[\XRLMNNMMMMLQTY\]]\]\\\\\\\][[\\\\[[[\ZTMHIJIIHFEDCCH=>Q]ZZ`]]^_`ceg||\F5(02578854387488?Repz|{}}|}}}|zz}ujleaUUUUUUUUUVVVWWXXWXYZZZZZZYXXXXYZWUQKGCAABCEGIKMMQPNXlpii^\YVUTTTUUVWWWWVVVVVVVVVVROJFDJQTUSQOQX][[\]^]\\XZ\^]WOJNPPOONMLKOUYZ\]^]]]]]]^]^^_^^^\\XVRLHGHJHHGEDBA@C<CXb[X]__^^_cegmsmS;1235458;:61386377>Qepz}|}}}}~|{}wngngbWWWWWWWWWWWXXXXYZZZZYYYYYXXXXXXXWVTOKFBAA@BBCDFEILJO[]aoe`[WWVTPTUVWWWWWVVVVVVVVURPMGBGOTUTPLNT[Z]`bba_]QUYZWQMJOOOPONMMKMPSTW\_]]]]]]^^```^\ZXVQNJGGGGFHGFDCA@@=>J\_XW_^^```abcYRG<646768;?@=83276376>Pdpz}|~}}}~}|unlmogbXXXXXXXXWXXXXXYY]\ZYXWWXYYYYXXXXYWVTOJFD>?@@@AAACJIGIISjjc[XYXSNTTUWWWWWVVVVVVVVTPOOHAEMJOUVTUZ_acdc^WPLJOSTPMKKMMNOOONNNNMNOT\a^]]^]]]^`_^ZXSQOJHEEGHFCGFFECA@@<BPZWSXd\^`bbb``PA57=<5/17>BB<73275376=Pdoz||~}}~~~}}xlhmtphbYYYYYYYYYYYYYYYYZZZZZZZZZZZZZZZZWWVWUOHDA@=<=>>=CC=BKDOtyoea`[WVPQRSSTWYXXXXWWWWLOPMGDEISPNOTZbgdeaVPOMJMMKJIIIIKKLMNOOPLLLLNQUW[]_``_]\b_ZSMIGFIHGGFFFFCBBBBA?=9KXVTX[Xbb[Za_^hLE?@=7464GTQF=95487684=Rfqz{z|}~~wnlosuphbYYYYYYYYYYYYYYYYZZZZZZZZZZZZZZZZXXWWUQJFB@=<===<><<CA<Syruqf``\VUWXXWVUUVVVVVVVVYZXQHBBDIMT\bghiab]TNOPMNMLKIIIIIHIJKKKLOMLLMNQQWX[]_^^^[XSOKIGHHHGFEEFEDCBBA@>=@OXTRX[YZ_]^d^ZcNT[XH86=MW[QE<74376595=Rgqz|z}}~~}qkorrqphbYYYYYYYYYYYYYYYYZZZZZZZZZZZZZZZZZYYYWTNJDA?===<;=7>B9=[xdu}pegcZSTUTTSRQTSSSSTTTOONJDCEHV[ahiheb_^XPNPRQOOMKIIHGEFFGGHIHLKKJJLNNQRTWWYXXQOLJHHHIHGFEDDDEDCCA@?>=GQWRPVZYX]\_d__jpwyhJ8>McbYK@:74254596=Rgr{|{}}}~}tjjruslogaYYYYYYYYZZZZZZZZ[[[[[[[[[[[[[[[[\[ZZYVRNHDA?>=<:=8A?8LffQfyxpjeaUTRRSUVVZZZZ[[[Z\]]]\^bejiifeb`_a]UPNPQRONLJHGGFDDDEEFFFFFFFHKMMNMNOOONMKJHGGGHIGFECCCCDCCCA?>?>NRTPPU[\Z][[bbhxqXDAQbd[LA;985253597=Qeq{}|~}}~~qlimsvrmnf`YYYYYYYYZZZZZZZZ[[[[[[[[[[[[[[[[]\[[[YVSKHD@>><:>=@<@_hNGUn~ohlc`ZXZ^aaddeeffggopnkjjlnhfdbbbdde^UPOOOPNLKIHGFFDDDDEEEECDDEFHIIKJJKKJJJIIHGFGFFEDCBBABBABB@==?@QQQOQX]_[^\]cbdqeYJCKXejYM@9::963524:7=Nbny||~~~~~whjnrsssqnd^YYYYYYYY[[[[[[[[\\\\\\\\\\\\\\\\]\[\\[YVPLGCA><:==>?Md_BQTj~txoha]^abacddeffggfedcccbbaabccb`_e\SRPNLMKJIGFFFFEEEEEEFFEFEDDCCBGFGIJLLNIHHGGFEDDCBA???@?AA?<=ACTRPQUZ]^W]^af\QUC@AL`kfYOC99<;743524:7;L^jx{{~~~}woglrsrqqrlc]YYYYYYYY[[[[[[[[\\\\\\\\\\\\\\\\][[\]\YXTPKFC@=;;<=K\[QO[Ybwysje^\^_][^^___`aa``bdfggfbcddb`\[bXQPQMKKHHGFEEFFEFEFFFFEEEEDCBAAEDEFFIJKGGGGFFDDBCA@????<?A><=AFVSRTX[ZYX\[aeWDABLXaggZLF:47=<644525;79IZguz{~zqjlnpqrrpokc\YYYYYYYY[[[[[[[[\\\\\\\\\\\\\\\\\[[[]\ZYVRLHDA><<<@XhRHbZUT^pzp`c_\]aa]X^^_`aaab_`aceda_cb`__abc_TNPQMJJGFFEEEFGDEEEEEEEABCCDDCCDCBBBBCCEEFFFFEDCBA??>>?<>A><=BHYTRVZZXV\\XZaSA>J[gf\WRN>3.5;:667635;68GWery{}}tmiqomorsplkc\YYYZZ[[[ZZZZZZZZ[[[[[[[[\\\\\\\\X[_^\ZYZYYVNJGA;?9Gg|uhaXY\_acee__`aa^]_\]]^_`_^bbbccddcbb`````a^XPLKLJHHHGEEEEFFFFEEDDDDDDDDDDDCCCBBBBBCBCBBAAAAA@A??>=:><;><?NWWVWVXYZ[Z]aYLJPlf]YVQKE84137;:72233679:Qaqyz}}ollklnpsrpmkj`WYYYZZ[[[ZZZZZZZZ[[[[[[[[\\\\\\\\]\]]``^\[_a^ZVMEC9<NXSNPeeccbbaaj`WW]`\W\]^_aa``bbbccdddcba````a`[UNKIHFIHGFEEEFFFEEEDDDCCCCDDDDCCCCCCCCCCCBBBAAAA@?>>>>9?<;>;>NVWWWYYZ[VW[`a_bgb\UPOMID;73369863345579:N]muy}wljjilmoqpnlkh^VYYYZZ[[[ZZZZZZZZ[[[[[[[[\\\\\\\\^ZXZ_`][ZcnqpkaWK>8==8:B>AEKSZbeld[X]`_[\]_abbbbbbbbccccbba``````^ZSLGEEIHFFEEEFFEEEDDDDCCDDDDDDCCCCCBBBDDCCBBBB@@??>===9><:=:>MVVWXZ[\\\]]\`fhfUOJGHIGF>:64576455555789JYhqw}yoiiiglmnpomljf\TYYYZZ[[[ZZZZZZZZ[[[[[[[[\\\\\\\\^[ZY[]^^^kzxoXJ>>=89@87789=@BS]b`[[_b]^^`abbbbbbbbbbcba`a__`a_`^WNHFFIHGFEEEFEEEDDDCCCCDDDDDDCCCBBBBADCCCBBBB???>===<9>;9<9=LVVWYZ\]^_a\TV\YOHD@?AEFGA=85665466456678GVeow~}qigiigllmnmlkjdZRYYYZZ[[[ZZZZZZZZ[[[[[[[[\\\\\\\\`ba][^fnup\IA@==@DA>954336GW[[]_^^^`aaaaabbbbbbbabaa`````]^^YRJIHHGFFEEEFEEDDDCCCDDDDDDDDCCCBBAA@CCBBBAAA?>>=<<<<9>;9;9<KVVXZ[\]\YZUNOSM@<:779>BDA>;8764255545577DRcnxxkefiihklmmlkjieZQYYYZZ[[[ZZZZZZZZ[[[[[[[[\\\\\\\\[^`]]exx[IA<;<;;99:<>?19BM\ig]babbbbaabbbbaaaaaaa`__``[\][VOKIHHGFEEEFDDDDCDCBDDDDDDDDCCBBA@@@AAAA@A@@>>=<<<;;9=:9;8;IUVXZ[[Z[YVQKJG?63211259<>>=<:75333333477AO`ny}pecghhikkkkkjihdXPYYYZZ[[[ZZZZZZZZ[[[[[[[[\\\\\\\\Z[]_h{fRD<:?>=:7533787=Qipkggffedcbbbbaa``aa`_`__``]]][XRKFHGGFEEEFDDDCCCBCDDDDDDDDCCBBA@?@@A@?@>>>>>==<;::8=;8;6:HVVX[[ZYYXPIEA92000/..024:<>><96400013556=K^mysiacfffhjjjjiihhaWMYYYZZ[[[ZZZZZZZZ[[[[[[[[\\\\\\\\```hzŸlSD???>=;9766940<Yqzllkigfcbbbbaa```a`_____``^]\ZTJCHGFFEEFFDDDDCBCCDDDDDDDDCCBA@A@?@?>?>>>>>>=<;;:;9=;7969HUXYZZYXVMB;<80/51221//018;?@>;64/./02457;I\ly}lc_cfddgjjiiihhh_TK[[[[[[[[[[[[[[[[[[[\\]]]]]]]]]]][\k̾xW??>>>94498977Hk~lghgffcfaZ]ecZ^^_^^]\\a^\ZXSKFIHGGFEFEDCCBBBBBCCCCCCCCEDCBA@??>>>>>>>>:>@?<99:7=83658DVXWVY\SH><:74333331100//049=><85-,,-03575EZm{xfb__bdedhllhfijh_RF[[[[[[[[[[[[[[[[[[[\\]]]]]]]]]]]\f{Ͻu^FA<<:88:6<CNeвpjkf_`acfb[[_]]_^^^]\_^\[YTLGIHGGFEEEDCCBCBBBCCCCCDDDDCBAA?>>>>>>>>>>=>?@>;997:54846DPW[YUND897754444322210/0037;=<:80.-,.0356D[m|}tdb__accceiifehhf\OC[[[[[[[[[[[[[[[[[[[\\]]]]]]]]^^^\qðZL><>?=;8F[p٬sX]kme]]aaa`[\^]_^^]]]]]ZUMHIHGGFEFFCCDCCBBBDDDDDDDDBBA@?>==>>>>>>>>@????=:78736936ITYZSH?6022344444343221000259;<<<63.++-135E\pymb`]]_abbcegeegfcWI<[[[[[[[[[[[[[[[[[[[\\]]]]]]^^^^_b|ìx`G?AB>;C[zԸsUdhe]_fe\[\\^^^^^[\^^[UNJIHGGFEFFCCDCCBBBEEEDDDDDA@@?>=<<========A><=>>:7;848908Q]WMA9555013454333333221101358;=>:71,*+.13F`wtd]]\\]^__`cedfgd_OA4[[[[[[[[[[[[[[[[[[[\\]]]]]]^^__`hѽtRBBA?<WuڪrZ`ileZY][[\]^^^^\]_]YTOKIHGFFEFFDDDCCBBBEEEDDCCC>?>>=<<<========?<;;==:7896660;VXL=424452345532133222211001259;=<:4/,+-.1Ge{}jYZZZZZZ\\_ceeggbZH:-[[[[[[[[[[[[[[[[[[[\\]]]]]^^_```ewĲ\GBDFHqϖnWbfYUa[\\]]]]\]^^\WQLKHHGGFEFFDDDCCBBBEDDCCBAA>>>>==<===<<<<<<=<;;<=<;8<759:ASE:213410343332101111111100012589;:730.--/Hhy|raRVWYYWWXZ^befgg^U?2'[[[[[[[[[[[[[[[[[[[\\]]]]]^^_`aaajɸeOINXa٫v`_`^^]]]^]\[[^_^ZSNLKIHGGFEFFDDDCCBBBDDCBA@@?>>>>>====<<<<<<<<=>>=>@B=A;:GOLN610351./22100000/0000000100/01349:9952.,1IerpdYOSUWWUUVX^acefdZN9-$[[[[[[[[[[[[[[[[[[[\\\]]]]^_``abfjlWQYkyǂZ_bV^^^^]\[[__^YRLJKIHGGFEEEDDDCCBBBCCBA@??>??>>>>>==<=<<<<<;>A@??CGDH?@VcWJ52353./60/.--/01.///////1000000079<;95/,2JckdZSNQUWWUSUW]`ccebWK5+"\\\\\\\\\\\\\\\\\\]]]^^^X\bc]]iyhY_oݥgR_`\[]ab`^]]]YTOMMKKIGFEEEDDCBAA@?@@AA@?=<>>>==<<<;<=>=<:::<????ADDIG[frwE33322211000//.........../..--../3579;9756FX\TJFHQSTTSRTW]acdd_QB*'%\\\\\\\\\\\\\\\\\\\]]^^^[^aa^dvͼdU^r༃W\]``[TV[\^^ZUPNOLJIGFEEEDDCCBA@@?@@@@>=<>>>===<<::;<>>>?=>?@@BCEHNO`m{xD32221110000//.........../.----./024799989EQSKCDHQRSSQQRS[_cdb\L=*(%\\\\\\\\\\\\\\\\\\\]]^^^__aabnȸldn˞U]ZQZliV[^_[SNNPKJJHGFFFDDCCBAAAAAAA@?=<>>>>===<;;;<=>@@A@?@CEEEHRTbut?2111000/000//.............-,,-....12579:;AGE>;@GPQSRPONOY^cd`WE5*(&\\\\\\\\\\\\\\\\\\\]]^^^``acgxŵ㼂XZf^X\X]_[TNMOKKIHGGFFDDDCCCCBAAA@?>>=??>>>===@?====>>CA@ADFFFHQVbwf511000///000//...----------,,,,---,./14789=>:55;AJMPQPNNMX^dd^S@/(&%\\\\\\\\\\\\\\\\\\\]]^^^^_cfk|ƹҘfTY_^W[]ZSNLNKKJIHHHHEDDCCCDCCBA@@??????>>>==A@>>>>>?DBCDFGGFHPZdwzU211000///000//...--------,,++++,-/.---0244777337;BFKMNNOPW_fe\O;+'%#\\\\\\\\\\\\\\\\\\\]]^^^^`cglzɾߡnbaZXZ[ZVQMLLLJHHHHHEEEEEDDDEDCA@@@A@???>>>>==>>?BBCBFIJJHGHKQ_hvnE42111000/000//...,,,,,,,,,+****+-./----/0/2676556;>CGJMOQW_ecYK8)'%#\\\\\\\\\\\\\\\\\\\]]^^^`abcgtxVe]\\\ZWPLLKJJHIIHEEEEEEEEGFDBABBC@@???>>>==>ABBBCCJQRNJIKNPbjt`4832221110000//...,,,,,,,,++*))*+,-.----./.148987658<@CGKNU]c_VG5')'%\\\\\\\\\\\\\\\\\\\]]^^^bba`aoקra^\]^ZSLLKJIIHHHEEEEEEEEGGECBBCD@?@??>>>?ABCCA@@BLVWQKKNMMbjoT):33322211000//...,,,,,,,,+**))**+,,-.-.//.048;:98258;>BHKS[a\RD2%+)'\\\\\\\\]]]]]]]]]]]^^^__dbcffnۂhW\c\VYIIHFDDFHCDDEFFFEGEEEEDDD??@AA@@@A?GF<76.JFACP[WKNUgr_>/4443332222221000/00//....++++++**.-----..+-059<>@97534:CIOV\XL=1,)((\\\\\\\\]]]]]]]]]]]^^^__dacfhpܬu^^_]ZPOMKIGECFEEFFCDGEEEDDCCCABCCCCCCG@EF:451CA><DQWVO[jlT:196555444444433222111000//--,,++**++***++,.-.049>A<;8658=ALSXVL>3-,*)\\\\\\\\]]]]]]]]]]]^^^__bacghqܷZT^aXKCCDGIDBCGFDFLCCCCBBBBBCCEDDCCI?ENB68;<><79EU^WemaE34<677766657766655543332221//.-,+**((((()*+0.++.4;@A@>;7568FLRRJ>50---[[\\\\]]]]]]]]]]]]]^^___bacfgoȋSKJKORND;PHGHG?<@BBBBAAAAACCCCBCAE>M`VC?B:=<87?OZbljT;37:788776668777777755555544220/.,++**))*+,,/-**,17:ABB?:643>DJKF=52/.-[[[\\]]]]]]]]]]]]]]^^___bbdeel¿ƫqUIINPHDDFJKLLBBBBBBCCDDDDDDBBBAZrgNCC;;==<>DKkncL;99678877666777777777776665554321/..,,++++,,++++-/24=ACC?;86:>CEB<50.-,[[[\\]^^]]]]]]]]]]]^^___bbdeckƿűn[\TC:<><DDDDEEEEGHHGGGEEDH`seNB<;;=@@>@ClgZJBB>688887777667777888888777666554322.-,+++++++,-...-6;@CB?<;9;?B?;50--,[[[\\]^^]]]]]]]]]]]^^___aadedk»ٿYKIDFFFGGHHHHHHIHGFEFJZbRD@;>>ACC?FNc\TNMIC<99999998777889999998877788776655310.,+**++,---,+05<@BA??;=@A?<62.-,ZZ[\\]^^]]]]]]]]]]]^^___`adfdmȿ̈́K>CCGGHHIIJJHHHGFEDCDGPM>;@>BCFGCCO_ZUQRSMGB;;;:::9988899:::999887779999888886420.----,,,+--+09?B@@@=>@AA<72/.-YZ[\^^_`]]\\\]]^^____^]\^_abeu|FGDCGGFFGGFGEFGGFECBFD?;<@BAJIDAJWYPPQRRPMJH?=;9889978899::::998899:9:9::<<=::986421.//014:>DEDDDCCC@EIKJF<1.,+YZ[\^_a`^^]]]^^_____^^]\_`cej|Ƽ{EFCCGGGGGGGGEFFGFFCCFC@=>BDEGINVVQMLMLMNMMMKDBA>;:9978899::::998899:::::;<==>?=<;97676547?HNZXUPJD@?BHOQQMC8-+*YZ[]^_aa``__^__`___^^]]]_^afoûyCDCCFGGHHGGFEEFFFFDCFDAABEIMLRbphREFHHHHIKLMJIFB?<;:789999::::9999::::::;<>=@@@?>=<;=;88=GU^hfaVKB<:AIRWXSH=1/-YZ[]_`abbba````a`_^^]]]]]\^eozCEDEFGHHHGFEDDEEEFEEHEEGHJPVbo~gUKEEDDEHKMLKHEA?=;89999999;:9999:;;::;;=>>>???>=<;<;88=IWadb]RE;53<EPVXTH=20-YZ[]_`bcdcba``aa`_^]]]^^^]^eo}|EGEFFGIIHGEDDDDDEFFGIFGLNOV`~lVFDCABDGIJIGEBA?>89999999;;:99:;;;;;;<=>>>?>>=<;;:978=GS[_^YOB6117AMTWSH<.+(
\ No newline at end of file
diff --binary -Nru3 grx246/test/speedtst.c tgrx246/test/speedtst.c
--- grx246/test/speedtst.c	2003-05-04 00:45:12.000000000 +0200
+++ tgrx246/test/speedtst.c	2004-01-22 19:11:47.858876800 +0100
@@ -26,7 +26,7 @@
 /*#include <wcdefs.h>*/
 #include <conio.h>
 #else
-#include <values.h>
+/* #include <values.h> */
 #endif
 #include <math.h>
 #include <time.h>
diff --binary -Nru3 grx246/xemacs-21.4.14.exe.stackdump tgrx246/xemacs-21.4.14.exe.stackdump
--- grx246/xemacs-21.4.14.exe.stackdump	1970-01-01 01:00:00.000000000 +0100
+++ tgrx246/xemacs-21.4.14.exe.stackdump	2004-02-09 06:17:30.876492800 +0100
@@ -0,0 +1,19 @@
+Stack trace:
+Frame     Function  Args
+0022E3D8  77E7AC21  (00000000, 00000000, 00543E30, 0174AB08)
+0022E438  61087E49  (000009F0, 00000006, 00000001, 00000020)
+0022E458  61086211  (00000006, 0043B830, 00000000, 00000000)
+0022E478  61026B4C  (00000638, 0000EA60, 00000014, 0022E4B4)
+0022E4F8  6108A855  (00000000, 370107B7, 00000010, 000000A6)
+0022E558  61087E49  (000009F0, 00000006, 0022E588, 610883B3)
+0022E568  61087EFC  (00000006, 00000000, 0022E594, 005BDDA3)
+0022E588  610883B3  (0043E500, 0046B7D0, 00000233, 0046B7FC)
+0022E5B8  61086211  (0046B7D0, 00000233, 0046B7FC, 00000004)
+0022E6C8  0046BCBB  (1032B400, 10396268, 103C2560, 000001F0)
+0022E798  0046CF5A  (1032B400, 10396268, 10390E80, 00000000)
+0022E7C8  0055CF36  (1032B400, 10396268, 00000000, 00000000)
+0022E818  0055FCF1  (1032B400, 103AE268, 10396268, 103A5D00)
+0022E8D8  0055C61F  (1032B400, 1034B780, 1034B900, 00000007)
+0022E938  0055F008  (1032B400, 00000CE0, 00001327, 00000CE0)
+0022E9A8  00559387  (1032B400, 00000000, 00000000, 00000000)
+End of stack trace (more stack frames may be present)
\ No newline at end of file
